@@ -15,16 +15,16 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains sensor that check the existence
-of a record in a Cassandra cluster.
-"""
+from __future__ import annotations
 
-from typing import Any, Dict
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.providers.apache.cassandra.hooks.cassandra import CassandraHook
 from airflow.sensors.base import BaseSensorOperator
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class CassandraRecordSensor(BaseSensorOperator):
     """
@@ -45,23 +45,27 @@ class CassandraRecordSensor(BaseSensorOperator):
 
     :param table: Target Cassandra table.
         Use dot notation to target a specific keyspace.
-    :type table: str
     :param keys: The keys and their values to be monitored
-    :type keys: dict
     :param cassandra_conn_id: The connection ID to use
         when connecting to Cassandra cluster
-    :type cassandra_conn_id: str
     """
 
-    template_fields = ('table', 'keys')
+    template_fields: Sequence[str] = ("table", "keys")
 
-    def __init__(self, *, table: str, keys: Dict[str, str], cassandra_conn_id: str, **kwargs: Any) -> None:
+    def __init__(
+        self,
+        *,
+        keys: dict[str, str],
+        table: str,
+        cassandra_conn_id: str = CassandraHook.default_conn_name,
+        **kwargs: Any,
+    ) -> None:
         super().__init__(**kwargs)
         self.cassandra_conn_id = cassandra_conn_id
         self.table = table
         self.keys = keys
 
-    def poke(self, context: Dict[str, str]) -> bool:
-        self.log.info('Sensor check existence of record: %s', self.keys)
+    def poke(self, context: Context) -> bool:
+        self.log.info("Sensor check existence of record: %s", self.keys)
         hook = CassandraHook(self.cassandra_conn_id)
         return hook.record_exists(self.table, self.keys)
